/*
 * libedata-cal.h
 *
 * This library is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef LIBEDATA_CAL_H
#define LIBEDATA_CAL_H

#define __LIBEDATA_CAL_H_INSIDE__

#include <libecal/libecal.h>
#include <libebackend/libebackend.h>

#define LIBICAL_GLIB_UNSTABLE_API 1

#include <libedata-cal/e-cal-backend-factory.h>
#include <libedata-cal/e-cal-backend.h>
#include <libedata-cal/e-cal-backend-intervaltree.h>
#include <libedata-cal/e-cal-backend-sexp.h>
#include <libedata-cal/e-cal-backend-sync.h>
#include <libedata-cal/e-cal-backend-util.h>
#include <libedata-cal/e-cal-cache.h>
#include <libedata-cal/e-cal-meta-backend.h>
#include <libedata-cal/e-data-cal-factory.h>
#include <libedata-cal/e-data-cal.h>
#include <libedata-cal/e-data-cal-view.h>
#include <libedata-cal/e-subprocess-cal-factory.h>

#undef LIBICAL_GLIB_UNSTABLE_API

#undef __LIBEDATA_CAL_H_INSIDE__

#endif /* LIBEDATA_CAL_H */
