
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef E_BACKEND_ENUMTYPES_H
#define E_BACKEND_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "e-backend-enums.h" */
#define E_TYPE_AUTHENTICATION_SESSION_RESULT	(e_authentication_session_result_get_type())
GType e_authentication_session_result_get_type	(void) G_GNUC_CONST;
#define E_TYPE_DBUS_SERVER_EXIT_CODE	(e_dbus_server_exit_code_get_type())
GType e_dbus_server_exit_code_get_type	(void) G_GNUC_CONST;
#define E_TYPE_SOURCE_PERMISSION_FLAGS	(e_source_permission_flags_get_type())
GType e_source_permission_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_OFFLINE_STATE	(e_offline_state_get_type())
GType e_offline_state_get_type	(void) G_GNUC_CONST;
#define E_TYPE_COLLECTION_BACKEND_PARTS	(e_collection_backend_parts_get_type())
GType e_collection_backend_parts_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_BACKEND_ENUMTYPES_H */

/* Generated data ends here */

