/*
 * libedataserverui.h
 *
 * This library is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef LIBEDATASERVERUI_H
#define LIBEDATASERVERUI_H

#define __LIBEDATASERVERUI_H_INSIDE__

#include <libedataserverui/e-buffer-tagger.h>
#include <libedataserverui/e-cell-renderer-color.h>
#include <libedataserverui/e-certificate-widget.h>
#include <libedataserverui/e-credentials-prompter.h>
#include <libedataserverui/e-credentials-prompter-impl.h>
#include <libedataserverui/e-credentials-prompter-impl-oauth2.h>
#include <libedataserverui/e-credentials-prompter-impl-password.h>
#include <libedataserverui/e-reminders-widget.h>
#include <libedataserverui/e-trust-prompt.h>
#include <libedataserverui/e-webdav-discover-widget.h>

#undef __LIBEDATASERVERUI_H_INSIDE__

#endif /* LIBEDATASERVERUI_H */
